@@ -176,13 +176,16 @@ def install_client(
 
 @client_group.command("patch")
 @click.option("--separator", help="Separator for nested commands")
+@click.option("--module", help="Module name to patch. Default from config.")
 @click.pass_obj
-def patch_client(config: CliConfig, separator: str | None = None):
+def patch_client(config: CliConfig, separator: str | None = None, module: str | None = None):
     """Patch client generated with openapi-python-client to support more nested commands."""
 
     separator = separator or CLI_SEPARATOR
 
-    patch_submodule(f"{config.client_module_name}.api", separator)
+    module = module or config.client_module_name
+
+    patch_submodule(f"{module}.api", separator)
 
     echo("Client patched successfully" | green, OK)
 
@@ -233,6 +236,8 @@ def generate_client(
             "--overwrite",
             "--output-path",
             tmp_client_path,
+            "--custom-template-path",
+            "openapi_cli/templates",
         ]()
     except Exception as e:
         raise click.UsageError(f"Failed to generate client: {e}" | red)
@@ -285,6 +290,7 @@ def generate_client(
     ):
         ctx.invoke(
             patch_client,
+            module=output.name,
         )
 
     url = HttpUrl(api_url)
